@@ -8,7 +8,7 @@
 
 #include "settings_advanced.h"
 #include "akregatorconfig.h"
-
+#include <KLocalization>
 #include <KLocalizedString>
 
 #include <QPushButton>
@@ -22,9 +22,8 @@ SettingsAdvanced::SettingsAdvanced(QWidget *parent)
 {
     setupUi(this);
 
-    connect(kcfg_UseMarkReadDelay, &QCheckBox::toggled, kcfg_MarkReadDelay, &KPluralHandlingSpinBox::setEnabled);
-
-    kcfg_MarkReadDelay->setSuffix(ki18ncp("Mark selected article read after", " second", " seconds"));
+    connect(kcfg_UseMarkReadDelay, &QCheckBox::toggled, kcfg_MarkReadDelay, &QSpinBox::setEnabled);
+    KLocalization::setupSpinBoxFormatString(kcfg_MarkReadDelay, ki18ncp("Mark selected article read after", "%v second", "%v seconds"));
 }
 
 #include "moc_settings_advanced.cpp"
