@@ -9,6 +9,8 @@
 */
 
 #include "mainwidget.h"
+#include "config-akregator.h"
+
 #include "abstractselectioncontroller.h"
 #include "actionmanagerimpl.h"
 #include "akregator_part.h"
@@ -40,7 +42,9 @@
 #include "tabwidget.h"
 #include "treenode.h"
 #include "types.h"
+#include "whatsnew/whatsnewtranslations.h"
 #include "widgets/searchbar.h"
+#include <PimCommon/WhatsNewMessageWidget>
 #include <WebEngineViewer/ZoomActionMenu>
 
 #include <KAboutData>
@@ -63,10 +67,14 @@
 #include <PimCommon/NeedUpdateVersionUtils>
 #include <PimCommon/NeedUpdateVersionWidget>
 #include <PimCommon/NetworkManager>
+#include <PimCommon/WhatsNewDialog>
 #include <algorithm>
 #include <chrono>
 #include <memory>
-
+#if HAVE_ACTIVITY_SUPPORT
+#include "activities/activitiesmanager.h"
+#include "akregator_plasma_activities_debug.h"
+#endif
 using namespace std::chrono_literals;
 
 using namespace Akregator;
@@ -111,6 +119,20 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
         }
     }
 
+    WhatsNewTranslations translations;
+    const QString newFeaturesMD5 = translations.newFeaturesMD5();
+    if (!newFeaturesMD5.isEmpty()) {
+        const bool hasNewFeature = (Settings::self()->previousNewFeaturesMD5() != newFeaturesMD5);
+        if (hasNewFeature) {
+            auto whatsNewMessageWidget = new PimCommon::WhatsNewMessageWidget(this);
+            whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
+            whatsNewMessageWidget->setObjectName(QStringLiteral("whatsNewMessageWidget"));
+            topLayout->addWidget(whatsNewMessageWidget);
+            Settings::self()->setPreviousNewFeaturesMD5(newFeaturesMD5);
+            whatsNewMessageWidget->animatedShow();
+        }
+    }
+
     m_horizontalSplitter = new QSplitter(Qt::Horizontal, this);
 
     m_horizontalSplitter->setOpaqueResize(true);
@@ -282,6 +304,12 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
         m_searchBar->slotSetStatus(Settings::statusFilter());
         m_searchBar->slotSetText(Settings::textFilter());
     }
+#if HAVE_ACTIVITY_SUPPORT
+    connect(Kernel::self()->activitiesManager(), &ActivitiesManager::activitiesChanged, this, [this]() {
+        m_selectionController->activitiesChanged();
+        qCDebug(AKREGATOR_PLASMA_ACTIVITIES_LOG) << " activities changed";
+    });
+#endif
 }
 
 void MainWidget::slotSettingsChanged()
@@ -738,6 +766,15 @@ void MainWidget::slotFeedModify()
     cmd->setSubscription(m_feedList, node->id());
     cmd->setSubscriptionListView(m_feedListView);
     cmd->start();
+
+#if HAVE_ACTIVITY_SUPPORT
+    if (Kernel::self()->activitiesManager()->enabled()) {
+        connect(cmd, &EditSubscriptionCommand::finished, this, [this]() {
+            qCDebug(AKREGATOR_PLASMA_ACTIVITIES_LOG) << " EditSubscriptionCommand finished. Potential activities changed";
+            m_selectionController->activitiesChanged();
+        });
+    }
+#endif
 }
 
 void MainWidget::slotNextUnreadArticle()
@@ -1282,6 +1319,14 @@ void MainWidget::slotFocusQuickSearch()
     m_searchBar->setFocusSearchLine();
 }
 
+void MainWidget::slotWhatsNew()
+{
+    WhatsNewTranslations translations;
+    PimCommon::WhatsNewDialog dlg(translations.createWhatsNewInfo(), this);
+    dlg.updateInformations();
+    dlg.exec();
+}
+
 void MainWidget::slotArticleAction(Akregator::ArticleViewerWebEngine::ArticleAction type, const QString &articleId, const QString &feed)
 {
     switch (type) {
